[Scummvm-cvs-logs] SF.net SVN: scummvm: [28070] scummvm/trunk/engines/saga/sndres.cpp

thebluegr at users.sourceforge.net thebluegr at users.sourceforge.net
Sat Jul 14 16:18:45 CEST 2007


Revision: 28070
          http://scummvm.svn.sourceforge.net/scummvm/?rev=28070&view=rev
Author:   thebluegr
Date:     2007-07-14 07:18:45 -0700 (Sat, 14 Jul 2007)

Log Message:
-----------
Improved check for the patched sound file used in ITE intro

Modified Paths:
--------------
    scummvm/trunk/engines/saga/sndres.cpp

Modified: scummvm/trunk/engines/saga/sndres.cpp
===================================================================
--- scummvm/trunk/engines/saga/sndres.cpp	2007-07-14 13:41:03 UTC (rev 28069)
+++ scummvm/trunk/engines/saga/sndres.cpp	2007-07-14 14:18:45 UTC (rev 28070)
@@ -177,9 +177,13 @@
 			resourceType = kSoundWAV;
 		} 
 		
-		// If the game has patch files, then it includes a patch file for sound resource 4, used in the intro.
-		// Don't treat this patch file as compressed sound. This file is always included if patch files are present
-		if ((_vm->getFeatures() & GF_COMPRESSED_SOUNDS) && !(_vm->getPatchesCount() > 0 && resourceId == 4)) {
+		bool patchedSound = false;
+		// If a patch file exists for sound resource 4 (used in ITE intro), don't treat this sound as compressed
+		if (_vm->getGameType() == GType_ITE && resourceId == 4 && 
+			(Common::File::exists("sound/p2_a.iaf") || Common::File::exists("sound/p2_a.voc")))
+			patchedSound = true;
+
+		if ((_vm->getFeatures() & GF_COMPRESSED_SOUNDS) && !patchedSound) {
 			if (soundResource[0] == char(0)) {
 				resourceType = kSoundMP3;
 			} else if (soundResource[0] == char(1)) {


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list